#[unsafe(no_mangle)]pub extern "C" fn comet_weak_upgrade(
weak: WeakGcRef,
) -> *mut HeapObjectHeaderExpand description
Upgrade weak ref. If it is still alive then pointer is returned otherwise NULL is returned.
#[unsafe(no_mangle)]pub extern "C" fn comet_weak_upgrade(
weak: WeakGcRef,
) -> *mut HeapObjectHeaderUpgrade weak ref. If it is still alive then pointer is returned otherwise NULL is returned.